fastapi\_contrib.serializers package
====================================

Submodules
----------

fastapi\_contrib.serializers.common module
------------------------------------------

.. automodule:: fastapi_contrib.serializers.common
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.serializers.openapi module
-------------------------------------------

.. automodule:: fastapi_contrib.serializers.openapi
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.serializers.utils module
-----------------------------------------

.. automodule:: fastapi_contrib.serializers.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: fastapi_contrib.serializers
   :members:
   :undoc-members:
   :show-inheritance:
